@@ -20,7 +20,7 @@ from .lib import WeakFunctionReferences
 
 
 class PyHtmlGuiInstance:
-    def __init__(self, parent: PyHtmlGui):
+    def __init__(self, parent: PyHtmlGui, app_instance: object, view_class: typing.Type[PyHtmlView]):
         self._parent = parent
         self._websocket_connections = []
         self._children = weakref.WeakSet()
@@ -29,7 +29,7 @@ class PyHtmlGuiInstance:
         self._call_number = 0
         self._function_references = WeakFunctionReferences()
         self._template_env.globals['_create_py_function_reference'] = self._create_function_reference
-        self._view = self._parent.view_class(parent.app_instance, self)
+        self._view = view_class(app_instance, self)
 
     @property
     def connections_count(self) -> int:
@@ -124,6 +124,9 @@ class PyHtmlGuiInstance:
                     if hasattr(self._view, "on_frontend_ready"):
                         self._view.on_frontend_ready(len(self._websocket_connections))
 
+                elif message['name'] == "ping":
+                    pass
+
                 else:
                     return_val = None
                     print("unknown python function", message['name'])
